Exception: Beachcomber::MissingSymbol
- Defined in:
- lib/beachcomber/errors.rb
Overview
Raised when a loaded libbeachcomber is missing a required bc_* symbol. Names the symbol and the bc_version() of what was actually loaded.
Raised when a loaded libbeachcomber is missing a required bc_* symbol. Names the symbol and the bc_version() of what was actually loaded.